Source
======

.. autoclass:: deepint.core.Source
   :exclude-members:
   :members:

.. autoclass:: deepint.core.SourceFeature
   :exclude-members:
   :members:

.. autoclass:: deepint.core.FeatureType
   :exclude-members:
   :members:

.. autoclass:: deepint.core.source.SourceInfo
   :exclude-members:
   :members:

.. autoclass:: deepint.core.source.SourceFeatures
   :exclude-members:
   :members:

.. autoclass:: deepint.core.source.SourceInstances
   :exclude-members:
   :members: